@@ -1,8 +1,21 @@
 import pytest
+import logging
+from _pytest.logging import caplog as _caplog
+from loguru import logger
 
 from gbd_mapping import causes, risk_factors, etiologies
 
 
+@pytest.fixture
+def caplog(_caplog):
+    class PropogateHandler(logging.Handler):
+        def emit(self, record):
+            logging.getLogger(record.name).handle(record)
+
+    handler_id = logger.add(PropogateHandler(), format="{message}")
+    yield _caplog
+    logger.remove(handler_id)
+
 
 @pytest.fixture
 def cause_list():
